[tor-commits] [chutney/master] Quote some shell variables in test-network.sh

2016-07-27 Thread teor
commit 32a809aab74c6d41883b7bb0df1f5ea6404497d9
Author: teor (Tim Wilson-Brown) 
Date:   Thu Jul 28 15:34:46 2016 +1000

Quote some shell variables in test-network.sh
---
 tools/test-network.sh | 14 +++---
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/tools/test-network.sh b/tools/test-network.sh
index f2069d6..4f1fdbe 100755
--- a/tools/test-network.sh
+++ b/tools/test-network.sh
@@ -3,7 +3,7 @@
 ECHO_N="/bin/echo -n"
 
 # Output is prefixed with the name of the script
-myname=$(basename $0)
+myname=$(basename "$0")
 
 until [ -z "$1" ]
 do
@@ -166,7 +166,7 @@ fi
 
 # Set the variables for the chutney network flavour
 export NETWORK_FLAVOUR=${NETWORK_FLAVOUR:-"bridges+hs"}
-export CHUTNEY_NETWORK=networks/$NETWORK_FLAVOUR
+export CHUTNEY_NETWORK="networks/$NETWORK_FLAVOUR"
 
 # And finish up if we're doing a dry run
 if [ "$NETWORK_DRY_RUN" = true ]; then
@@ -175,7 +175,7 @@ if [ "$NETWORK_DRY_RUN" = true ]; then
 fi
 
 cd "$CHUTNEY_PATH"
-./tools/bootstrap-network.sh $NETWORK_FLAVOUR || exit 2
+./tools/bootstrap-network.sh "$NETWORK_FLAVOUR" || exit 2
 
 # chutney starts verifying after 15 seconds, keeps on trying for 60 seconds,
 # and then stops immediately (by default)
@@ -196,8 +196,8 @@ fi
 
 if [ "$CHUTNEY_BOOTSTRAP_TIME" -ge 0 ]; then
   # Chutney will try to verify for $CHUTNEY_BOOTSTRAP_TIME seconds
-  ./chutney verify $CHUTNEY_NETWORK
-  VERIFY_EXIT_STATUS=$?
+  ./chutney verify "$CHUTNEY_NETWORK"
+  VERIFY_EXIT_STATUS="$?"
 else
   echo "Chutney network ready and running. To stop the network, use:"
   echo "$PWD/chutney stop $CHUTNEY_NETWORK"
@@ -211,8 +211,8 @@ if [ "$CHUTNEY_STOP_TIME" -ge 0 ]; then
   sleep "$CHUTNEY_STOP_TIME"
   # work around a bug/feature in make -j2 (or more)
   # where make hangs if any child processes are still alive
-  ./chutney stop $CHUTNEY_NETWORK
-  exit $VERIFY_EXIT_STATUS
+  ./chutney stop "$CHUTNEY_NETWORK"
+  exit "$VERIFY_EXIT_STATUS"
 else
   echo "Chutney network verified and running. To stop the network, use:"
   echo "$PWD/chutney stop $CHUTNEY_NETWORK"



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [chutney/master] Wait 5 seconds between data retries

2016-07-27 Thread teor
commit 2e665358be47c8e318e61c08b645b6233d77249e
Author: teor (Tim Wilson-Brown) 
Date:   Thu Jul 28 15:43:14 2016 +1000

Wait 5 seconds between data retries

This also improves chutney success rates on slow machines.

And fix a typo.
---
 lib/chutney/Traffic.py  | 6 +++---
 scripts/chutney_tests/verify.py | 2 +-
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/lib/chutney/Traffic.py b/lib/chutney/Traffic.py
index 881cac7..b5f75fd 100644
--- a/lib/chutney/Traffic.py
+++ b/lib/chutney/Traffic.py
@@ -292,11 +292,11 @@ class Source(Peer):
 debug("BUG: sent no bytes")
 self._sent_no_bytes += 1
 # We can't retry too fast, otherwise clients burn all their HSDirs
-if self._sent_no_bytes >= 3:
-print("Send no data %d times. Stalled." %
+if self._sent_no_bytes >= 2:
+print("Sent no data %d times. Stalled." %
   (self._sent_no_bytes))
 return -1
-time.sleep(3)
+time.sleep(5)
 self.outbuf = self.outbuf[n:]
 if self.state == self.CONNECTING_THROUGH_PROXY:
 return 1  # Keep us around.
diff --git a/scripts/chutney_tests/verify.py b/scripts/chutney_tests/verify.py
index ac601c9..67ca642 100644
--- a/scripts/chutney_tests/verify.py
+++ b/scripts/chutney_tests/verify.py
@@ -16,7 +16,7 @@ def run_test(network):
 status = _verify_traffic(network)
 # Avoid madly spewing output if we fail immediately each time
 if not status:
-time.sleep(2)
+time.sleep(5)
 print("Transmission: %s" % ("Success" if status else "Failure"))
 if not status:
 # TODO: allow the debug flag to be passed as an argument to

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [chutney/master] Give test-network.sh a configurable delay before starting or stopping

2016-07-27 Thread teor
commit d671658dab35571778572836a62485b95f5f7fc2
Author: teor (Tim Wilson-Brown) 
Date:   Thu Jul 28 15:24:19 2016 +1000

Give test-network.sh a configurable delay before starting or stopping

--start-time is the delay before verifying
--bootstrap-time is the delay while verifying before giving up
--stop-time  is the delay after verifying

In general, negative values stop immediately, leaving the network running.
(See the README for details.)

Implements feature #19764.
---
 README| 31 +--
 tools/test-network.sh | 69 ++-
 2 files changed, 80 insertions(+), 20 deletions(-)

diff --git a/README b/README
index a2f9f7c..a8024fa 100644
--- a/README
+++ b/README
@@ -34,7 +34,12 @@ itself.
 You can modify its configuration using command-line arguments, or use the
 chutney environmental variables documented below:
 
-  --delayCHUTNEY_BOOTSTRAP_TIME
+Timing Options:
+  --start-time   CHUTNEY_START_TIME
+  --bootstrap-time   CHUTNEY_BOOTSTRAP_TIME
+  --stop-timeCHUTNEY_STOP_TIME
+
+Traffic Options:
   --data CHUTNEY_DATA_BYTES
   --connections  CHUTNEY_CONNECTIONS
   --hs-multi-client  CHUTNEY_HS_MULTI_CLIENT
@@ -81,15 +86,25 @@ HS Connection Tests:
   # Default behavior is one client connects to each HS
   ./chutney stop networks/hs-025
 
-Waiting for the network to bootstrap:
+Waiting for the network:
 
-  Commands like "chutney verify" start immediately, and keep trying for
-  CHUTNEY_BOOTSTRAP_TIME seconds. If they haven't been successful after that
-  time, they fail.
+  The tools/test-network.sh script waits CHUTNEY_START_TIME seconds
+  (default: 15) before calling chutney verify, because that's the minimum
+  amount of time it takes to bootstrap a consensus containing relays.
+  (It takes 5 seconds for the authorities to create the first consensus,
+  then 10 seconds for relays to bootstrap, submit their descriptors, and be
+  included in the next consensus.) If CHUTNEY_START_TIME is negative, the
+  script leaves the network running, and exits immediately (without verifying).
 
-  The tools/test-network.sh script waits 15 seconds before calling chutney
-  verify, because that's the minimum amount of time it takes to bootstrap a
-  consensus containing relays.
+  Commands like "chutney verify" start immediately, and keep trying for
+  CHUTNEY_BOOTSTRAP_TIME seconds (default: 60). If it hasn't been
+  successful after that time, it fails. If CHUTNEY_BOOTSTRAP_TIME is negative,
+  the script leaves the network running, and exits after CHUTNEY_START_TIME
+  (without verifying).
+
+  The tools/test-network.sh script waits CHUTNEY_STOP_TIME seconds
+  after verifying, then exits (default: immediately). If CHUTNEY_STOP_TIME is
+  negative, the script leaves the network running, and exits after verifying.
 
 Changing the network address:
 
diff --git a/tools/test-network.sh b/tools/test-network.sh
index 1d4816e..f2069d6 100755
--- a/tools/test-network.sh
+++ b/tools/test-network.sh
@@ -32,10 +32,26 @@ do
   export NETWORK_FLAVOUR="$2"
   shift
 ;;
---delay|--sleep|--bootstrap-time|--time)
+# The amount of time chutney will wait before starting to verify
+# If negative, chutney exits straight after launching the network
+--start-time)
+  export CHUTNEY_START_TIME="$2"
+  shift
+;;
+# The amount of time chutney will try to verify, before failing
+# If negative, chutney exits without verifying
+--delay|--sleep|--bootstrap-time|--time|--verify-time)
+  # This isn't the best name for this variable, but we kept it the same
+  # for backwards compatibility
   export CHUTNEY_BOOTSTRAP_TIME="$2"
   shift
 ;;
+# The amount of time chutney will wait after successfully verifying
+# If negative, chutney exits without stopping
+--stop-time)
+  export CHUTNEY_STOP_TIME="$2"
+  shift
+;;
 # Environmental variables used by chutney verify performance tests
 # Send this many bytes per client connection (10 KBytes)
 --data|--data-bytes|--data-byte|--bytes|--byte)
@@ -161,15 +177,44 @@ fi
 cd "$CHUTNEY_PATH"
 ./tools/bootstrap-network.sh $NETWORK_FLAVOUR || exit 2
 
-# chutney verify starts immediately, and keeps on trying for 60 seconds
-CHUTNEY_BOOTSTRAP_TIME=${CHUTNEY_BOOTSTRAP_TIME:-60}
-# but even the fastest tor networks take 5 seconds for their first consensus
+# chutney starts verifying after 15 seconds, keeps on trying for 60 seconds,
+# and then stops immediately (by default)
+# Even the fastest chutney networks take 5 seconds for their first consensus
 # and then 10 seconds after that for relays to bootstrap and upload descriptors
-echo "Waiting 15 seconds for a consensus containing relays to be generated..."
-sleep 15
-./chutney verify $CHUTNEY_NETWORK
-VERIFY_EXIT_STATUS=$?
-# work around a bug/feature in make -j2 (or more)
-# 

[tor-commits] [chutney/master] Increase start time to 20 seconds to avoid rare network failures

2016-07-27 Thread teor
commit bad7c3e8e4cbb3d276e01b0853eaef39baac8667
Author: teor (Tim Wilson-Brown) 
Date:   Thu Jul 28 15:39:06 2016 +1000

Increase start time to 20 seconds to avoid rare network failures

Older and slower versions of tor can't quite bootstrap in 15 seconds.
(At least on slow machines.)
---
 README| 4 ++--
 tools/test-network.sh | 6 +++---
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/README b/README
index a8024fa..f720a81 100644
--- a/README
+++ b/README
@@ -89,9 +89,9 @@ HS Connection Tests:
 Waiting for the network:
 
   The tools/test-network.sh script waits CHUTNEY_START_TIME seconds
-  (default: 15) before calling chutney verify, because that's the minimum
+  (default: 20) before calling chutney verify, because that's the minimum
   amount of time it takes to bootstrap a consensus containing relays.
-  (It takes 5 seconds for the authorities to create the first consensus,
+  (It takes 5-10 seconds for the authorities to create the first consensus,
   then 10 seconds for relays to bootstrap, submit their descriptors, and be
   included in the next consensus.) If CHUTNEY_START_TIME is negative, the
   script leaves the network running, and exits immediately (without verifying).
diff --git a/pt/onioncircuits.pot b/pt/onioncircuits.pot
index 74aab60..4ceea5a 100644
--- a/pt/onioncircuits.pot
+++ b/pt/onioncircuits.pot
@@ -10,7 +10,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-05-31 14:42+0200\n"
-"PO-Revision-Date: 2016-07-27 22:54+\n"
+"PO-Revision-Date: 2016-07-27 23:20+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-onioncircuits] Update translations for tails-onioncircuits

2016-07-27 Thread translation
commit e2b97f31dfe71c22c22c98494e2c633fde1f65a7
Author: Translation commit bot 
Date:   Wed Jul 27 23:48:44 2016 +

Update translations for tails-onioncircuits
---
 pt/onioncircuits.pot | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/pt/onioncircuits.pot b/pt/onioncircuits.pot
index 74aab60..4ceea5a 100644
--- a/pt/onioncircuits.pot
+++ b/pt/onioncircuits.pot
@@ -10,7 +10,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-05-31 14:42+0200\n"
-"PO-Revision-Date: 2016-07-27 22:54+\n"
+"PO-Revision-Date: 2016-07-27 23:20+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-misc] Update translations for tails-misc

2016-07-27 Thread translation
commit 736728a192430db26b2ef47e585995862807016f
Author: Translation commit bot 
Date:   Wed Jul 27 23:46:18 2016 +

Update translations for tails-misc
---
 pt.po | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/pt.po b/pt.po
index d1a847d..2cc6462 100644
--- a/pt.po
+++ b/pt.po
@@ -22,7 +22,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-06-06 14:26+0200\n"
-"PO-Revision-Date: 2016-07-27 22:54+\n"
+"PO-Revision-Date: 2016-07-27 23:18+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-onioncircuits] Update translations for tails-onioncircuits

2016-07-27 Thread translation
commit 1b2fa1c2c75eec6de3df34f7bf6e99fb0fe59b54
Author: Translation commit bot 
Date:   Wed Jul 27 23:19:00 2016 +

Update translations for tails-onioncircuits
---
 pt/onioncircuits.pot | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pt/onioncircuits.pot b/pt/onioncircuits.pot
index 825d683..74aab60 100644
--- a/pt/onioncircuits.pot
+++ b/pt/onioncircuits.pot
@@ -10,7 +10,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-05-31 14:42+0200\n"
-"PO-Revision-Date: 2016-07-20 22:21+\n"
+"PO-Revision-Date: 2016-07-27 22:54+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -84,4 +84,4 @@ msgstr "IP:"
 
 #: ../onioncircuits:610
 msgid "Bandwidth:"
-msgstr "Largura de Banda:"
+msgstr "Largura de banda:"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-onioncircuits_completed] Update translations for tails-onioncircuits_completed

2016-07-27 Thread translation
commit 96f4857e2fae04a6e46447aae62f702394fd7d34
Author: Translation commit bot 
Date:   Wed Jul 27 23:19:03 2016 +

Update translations for tails-onioncircuits_completed
---
 pt/onioncircuits.pot | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pt/onioncircuits.pot b/pt/onioncircuits.pot
index 825d683..74aab60 100644
--- a/pt/onioncircuits.pot
+++ b/pt/onioncircuits.pot
@@ -10,7 +10,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-05-31 14:42+0200\n"
-"PO-Revision-Date: 2016-07-20 22:21+\n"
+"PO-Revision-Date: 2016-07-27 22:54+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -84,4 +84,4 @@ msgstr "IP:"
 
 #: ../onioncircuits:610
 msgid "Bandwidth:"
-msgstr "Largura de Banda:"
+msgstr "Largura de banda:"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-openpgp-applet] Update translations for tails-openpgp-applet

2016-07-27 Thread translation
commit 8a0aac9dac5aa1e9c0a7aa5d2d151a561f6ebb05
Author: Translation commit bot 
Date:   Wed Jul 27 23:18:48 2016 +

Update translations for tails-openpgp-applet
---
 pt/openpgp-applet.pot | 10 +-
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/pt/openpgp-applet.pot b/pt/openpgp-applet.pot
index 75b60b9..1231110 100644
--- a/pt/openpgp-applet.pot
+++ b/pt/openpgp-applet.pot
@@ -10,7 +10,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: ta...@boum.org\n"
 "POT-Creation-Date: 2015-08-10 15:55+0200\n"
-"PO-Revision-Date: 2016-07-27 22:48+\n"
+"PO-Revision-Date: 2016-07-27 23:07+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -65,15 +65,15 @@ msgstr "Fidedignidade desconhecida"
 
 #: bin/openpgp-applet:353
 msgid "Marginal Trust"
-msgstr "Fidedignidade Marginal"
+msgstr "Fidedignidade marginal"
 
 #: bin/openpgp-applet:355
 msgid "Full Trust"
-msgstr "Fidedignidade Total"
+msgstr "Fidedignidade total"
 
 #: bin/openpgp-applet:357
 msgid "Ultimate Trust"
-msgstr "Fidedignidade Máxima"
+msgstr "Fidedignidade máxima"
 
 #: bin/openpgp-applet:410
 msgid "Name"
@@ -81,7 +81,7 @@ msgstr "Nome"
 
 #: bin/openpgp-applet:411
 msgid "Key ID"
-msgstr "ID da Chave"
+msgstr "ID da chave"
 
 #: bin/openpgp-applet:412
 msgid "Status"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor_animation_completed] Update translations for tor_animation_completed

2016-07-27 Thread translation
commit f656dc3c7d33abb83065e193cce2a0ff5058d149
Author: Translation commit bot 
Date:   Wed Jul 27 23:17:19 2016 +

Update translations for tor_animation_completed
---
 pt.srt | 17 +
 1 file changed, 9 insertions(+), 8 deletions(-)

diff --git a/pt.srt b/pt.srt
index b57b367..fef3117 100644
--- a/pt.srt
+++ b/pt.srt
@@ -46,26 +46,27 @@ partilhar com estranhos desconhecidos,
 
 11
 00:00:31,700 --> 00:00:34,000
-të cilët lehtësisht mund ti përdorin këto të dhëna
-për të të shfrytëzuar ty.
+quem poderá utilizar estas dados
+para o explorar
 
 12
 00:00:34,500 --> 00:00:37,000
-Por jo, në qoftë se ju jeni duke përdorur Tor!
+Mas não se você utilizar o Tor!
 
 13
 00:00:37,140 --> 00:00:40,840
-Tor Browser mbron privatësinë tonë
-dhe identitetin në internet.
+O Tor Browser protege a sua privacidade
+e identidade na Internet.
 
 14
 00:00:41,560 --> 00:00:44,760
-O Tor protege a ligação usando três camadas de encriptação
+O Tor protege a sua ligação
+atraves de três camadas de encriptação
 
 15
 00:00:44,940 --> 00:00:49,760
-dhe kalon nëpërmjet tre serverat
-shfrytëzimi në mbarë botën, vullnetarisht,
+e passa-a através de três
+servidores no mundo
 
 16
 00:00:50,280 --> 00:00:53,520

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor_animation] Update translations for tor_animation

2016-07-27 Thread translation
commit fed40eb3d8a730e75fbd302d4ca68f36bbc58a0f
Author: Translation commit bot 
Date:   Wed Jul 27 23:17:15 2016 +

Update translations for tor_animation
---
 pt.srt | 17 +
 1 file changed, 9 insertions(+), 8 deletions(-)

diff --git a/pt.srt b/pt.srt
index b57b367..fef3117 100644
--- a/pt.srt
+++ b/pt.srt
@@ -46,26 +46,27 @@ partilhar com estranhos desconhecidos,
 
 11
 00:00:31,700 --> 00:00:34,000
-të cilët lehtësisht mund ti përdorin këto të dhëna
-për të të shfrytëzuar ty.
+quem poderá utilizar estas dados
+para o explorar
 
 12
 00:00:34,500 --> 00:00:37,000
-Por jo, në qoftë se ju jeni duke përdorur Tor!
+Mas não se você utilizar o Tor!
 
 13
 00:00:37,140 --> 00:00:40,840
-Tor Browser mbron privatësinë tonë
-dhe identitetin në internet.
+O Tor Browser protege a sua privacidade
+e identidade na Internet.
 
 14
 00:00:41,560 --> 00:00:44,760
-O Tor protege a ligação usando três camadas de encriptação
+O Tor protege a sua ligação
+atraves de três camadas de encriptação
 
 15
 00:00:44,940 --> 00:00:49,760
-dhe kalon nëpërmjet tre serverat
-shfrytëzimi në mbarë botën, vullnetarisht,
+e passa-a através de três
+servidores no mundo
 
 16
 00:00:50,280 --> 00:00:53,520

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-iuk] Update translations for tails-iuk

2016-07-27 Thread translation
commit 1b120b0b1459d21ef7952d8501d956191951390e
Author: Translation commit bot 
Date:   Wed Jul 27 23:16:59 2016 +

Update translations for tails-iuk
---
 pt.po | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pt.po b/pt.po
index a887932..0c12f27 100644
--- a/pt.po
+++ b/pt.po
@@ -15,7 +15,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: Tails developers \n"
 "POT-Creation-Date: 2016-05-25 16:55+0200\n"
-"PO-Revision-Date: 2016-07-27 22:41+\n"
+"PO-Revision-Date: 2016-07-27 23:15+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -89,7 +89,7 @@ msgstr "A atualização disponível requer %{space_needed}s 
de espaço livre na
 msgid ""
 "The available incremental upgrade requires %{memory_needed}s of free memory,"
 " but only %{free_memory}s is available."
-msgstr "A atualização disponível requer %{memory_needed}s of free memory, 
mas apenas %{free_memory}s está disponível."
+msgstr "A atualização disponível requer %{memory_needed}s de memória 
livre, mas você apenas dispões de %{free_memory}s."
 
 #: ../lib/Tails/IUK/Frontend.pm:357
 msgid ""

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/torbirdy] Update translations for torbirdy

2016-07-27 Thread translation
commit 3b948dc94d99a57533bff58f0d031b818fa74192
Author: Translation commit bot 
Date:   Wed Jul 27 23:15:59 2016 +

Update translations for torbirdy
---
 pt/torbirdy.dtd | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pt/torbirdy.dtd b/pt/torbirdy.dtd
index d299b2a..e72fb0c 100644
--- a/pt/torbirdy.dtd
+++ b/pt/torbirdy.dtd
@@ -12,9 +12,9 @@
 
 
 
-
+
 
-
+
 
 
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/mat-gui_completed] Update translations for mat-gui_completed

2016-07-27 Thread translation
commit 57d30dce87b5431ef7d036c11f96448701b3b109
Author: Translation commit bot 
Date:   Wed Jul 27 23:16:11 2016 +

Update translations for mat-gui_completed
---
 pt.po | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pt.po b/pt.po
index 279f439..99591f3 100644
--- a/pt.po
+++ b/pt.po
@@ -12,7 +12,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-02-10 23:06+0100\n"
-"PO-Revision-Date: 2016-07-20 22:23+\n"
+"PO-Revision-Date: 2016-07-27 23:13+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -69,7 +69,7 @@ msgstr "Preferências"
 
 #: mat-gui:232
 msgid "Reduce PDF quality"
-msgstr "Reduzir qualidade PDF"
+msgstr "Reduzir qualidade do PDF"
 
 #: mat-gui:235
 msgid "Reduce the produced PDF size and quality"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-misc] Update translations for tails-misc

2016-07-27 Thread translation
commit ecc3bd9667f8fe3c578538b9408dc4ea7cbec33c
Author: Translation commit bot 
Date:   Wed Jul 27 23:16:32 2016 +

Update translations for tails-misc
---
 pt.po | 12 ++--
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/pt.po b/pt.po
index d4bf591..d1a847d 100644
--- a/pt.po
+++ b/pt.po
@@ -22,7 +22,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-06-06 14:26+0200\n"
-"PO-Revision-Date: 2016-07-27 22:46+\n"
+"PO-Revision-Date: 2016-07-27 22:54+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -97,23 +97,23 @@ msgstr "Informações"
 
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:192
 msgid "Encrypt Clipboard with _Passphrase"
-msgstr "Encriptar o Clipboard com _Passphrase"
+msgstr "Cifrar a área de transferência com uma _palavra-passe"
 
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:195
 msgid "Sign/Encrypt Clipboard with Public _Keys"
-msgstr "Assinar/Encriptar área de transferência com Public _Keys"
+msgstr "Assinar/encriptar a área de transferência cha_ves públicas"
 
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:200
 msgid "_Decrypt/Verify Clipboard"
-msgstr "_Desencriptar/Verificar área de transferência"
+msgstr "_Decifrar/verificar área de transferência"
 
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:204
 msgid "_Manage Keys"
-msgstr "_Gerir Chaves"
+msgstr "_Gerir chaves"
 
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:208
 msgid "_Open Text Editor"
-msgstr "_Open Editor de Texto"
+msgstr "Abrir edit_or de texto"
 
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:252
 msgid "The clipboard does not contain valid input data."

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/mat-gui] Update translations for mat-gui

2016-07-27 Thread translation
commit 8e45eb29cd90762f17abf6b0eaff525a8c48f97c
Author: Translation commit bot 
Date:   Wed Jul 27 23:16:07 2016 +

Update translations for mat-gui
---
 pt.po | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pt.po b/pt.po
index 279f439..99591f3 100644
--- a/pt.po
+++ b/pt.po
@@ -12,7 +12,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-02-10 23:06+0100\n"
-"PO-Revision-Date: 2016-07-20 22:23+\n"
+"PO-Revision-Date: 2016-07-27 23:13+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -69,7 +69,7 @@ msgstr "Preferências"
 
 #: mat-gui:232
 msgid "Reduce PDF quality"
-msgstr "Reduzir qualidade PDF"
+msgstr "Reduzir qualidade do PDF"
 
 #: mat-gui:235
 msgid "Reduce the produced PDF size and quality"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-persistence-setup_completed] Update translations for tails-persistence-setup_completed

2016-07-27 Thread translation
commit c4930397035c754f35757bf45b971baec70c59d4
Author: Translation commit bot 
Date:   Wed Jul 27 23:15:48 2016 +

Update translations for tails-persistence-setup_completed
---
 pt/pt.po | 8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/pt/pt.po b/pt/pt.po
index ec7e0a9..e1e90f0 100644
--- a/pt/pt.po
+++ b/pt/pt.po
@@ -20,7 +20,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: Tails developers \n"
 "POT-Creation-Date: 2016-05-25 02:27+0200\n"
-"PO-Revision-Date: 2016-07-27 22:45+\n"
+"PO-Revision-Date: 2016-07-27 23:08+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -67,15 +67,15 @@ msgstr "Icedove"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:90
 msgid "Icedove profiles and locally stored email"
-msgstr "Perfil do Icedove e email armazenado localmente"
+msgstr "Perfis Icedove e email armazenado localmente"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:98
 msgid "GNOME Keyring"
-msgstr "Keyring GNOME"
+msgstr "Chaveiro GNOME"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:100
 msgid "Secrets stored by GNOME Keyring"
-msgstr "Segredos guardados pelo Keyring GNOME"
+msgstr "Segredos guardados pelo chaveiro GNOME"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:108
 msgid "Network Connections"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-greeter_completed] Update translations for tails-greeter_completed

2016-07-27 Thread translation
commit 6ae79fa2538b896f825f1ba96402e0c49ce62f44
Author: Translation commit bot 
Date:   Wed Jul 27 23:15:55 2016 +

Update translations for tails-greeter_completed
---
 pt/pt.po | 8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/pt/pt.po b/pt/pt.po
index dca8257..4815c60 100644
--- a/pt/pt.po
+++ b/pt/pt.po
@@ -15,7 +15,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-06-05 19:35+0200\n"
-"PO-Revision-Date: 2016-07-27 22:38+\n"
+"PO-Revision-Date: 2016-07-27 23:01+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -58,7 +58,7 @@ msgstr "Palavra-passe"
 
 #: ../glade/persistencewindow.glade.h:9
 msgid "Read-Only?"
-msgstr "Só de leitura?"
+msgstr "Apenas leitura?"
 
 #: ../glade/persistencewindow.glade.h:10
 msgid "Wrong passphrase. Please try again."
@@ -82,7 +82,7 @@ msgstr "Passwords do not match"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/liveusb-creator] Update translations for liveusb-creator

2016-07-27 Thread translation
commit c16b1d50c96341a4b50a52d91c630f8b4337fbe0
Author: Translation commit bot 
Date:   Wed Jul 27 23:15:38 2016 +

Update translations for liveusb-creator
---
 pt/pt.po | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/pt/pt.po b/pt/pt.po
index bc65983..b97c68f 100644
--- a/pt/pt.po
+++ b/pt/pt.po
@@ -20,7 +20,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2015-11-02 21:23+0100\n"
-"PO-Revision-Date: 2016-07-27 22:35+\n"
+"PO-Revision-Date: 2016-07-27 22:52+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-persistence-setup] Update translations for tails-persistence-setup

2016-07-27 Thread translation
commit 228e3e6cf63e61ea22f562ea9e1b54503d4dad0c
Author: Translation commit bot 
Date:   Wed Jul 27 23:15:44 2016 +

Update translations for tails-persistence-setup
---
 pt/pt.po | 8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/pt/pt.po b/pt/pt.po
index ec7e0a9..e1e90f0 100644
--- a/pt/pt.po
+++ b/pt/pt.po
@@ -20,7 +20,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: Tails developers \n"
 "POT-Creation-Date: 2016-05-25 02:27+0200\n"
-"PO-Revision-Date: 2016-07-27 22:45+\n"
+"PO-Revision-Date: 2016-07-27 23:08+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -67,15 +67,15 @@ msgstr "Icedove"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:90
 msgid "Icedove profiles and locally stored email"
-msgstr "Perfil do Icedove e email armazenado localmente"
+msgstr "Perfis Icedove e email armazenado localmente"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:98
 msgid "GNOME Keyring"
-msgstr "Keyring GNOME"
+msgstr "Chaveiro GNOME"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:100
 msgid "Secrets stored by GNOME Keyring"
-msgstr "Segredos guardados pelo Keyring GNOME"
+msgstr "Segredos guardados pelo chaveiro GNOME"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:108
 msgid "Network Connections"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/torbirdy_completed] Update translations for torbirdy_completed

2016-07-27 Thread translation
commit 3f654f4d68d9303b836397522a69ac93f6747a11
Author: Translation commit bot 
Date:   Wed Jul 27 23:16:03 2016 +

Update translations for torbirdy_completed
---
 pt/torbirdy.dtd | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pt/torbirdy.dtd b/pt/torbirdy.dtd
index d299b2a..e72fb0c 100644
--- a/pt/torbirdy.dtd
+++ b/pt/torbirdy.dtd
@@ -12,9 +12,9 @@
 
 
 
-
+
 
-
+
 
 
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/https_everywhere_completed] Update translations for https_everywhere_completed

2016-07-27 Thread translation
commit 2198c968f9a0195b9be0fddc35400fc71a135940
Author: Translation commit bot 
Date:   Wed Jul 27 23:15:34 2016 +

Update translations for https_everywhere_completed
---
 pt/ssl-observatory.dtd | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/pt/ssl-observatory.dtd b/pt/ssl-observatory.dtd
index 6d844a9..57dd073 100644
--- a/pt/ssl-observatory.dtd
+++ b/pt/ssl-observatory.dtd
@@ -34,7 +34,7 @@ to turn it on?">-->
 
 
 
+"Verificar certificados utilizando o Tor para anonimato (requer o Tor)">
 
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-greeter] Update translations for tails-greeter

2016-07-27 Thread translation
commit 02a74e92fd77305128ccd1bf0c5d465697edcc82
Author: Translation commit bot 
Date:   Wed Jul 27 23:15:51 2016 +

Update translations for tails-greeter
---
 pt/pt.po | 8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/pt/pt.po b/pt/pt.po
index dca8257..4815c60 100644
--- a/pt/pt.po
+++ b/pt/pt.po
@@ -15,7 +15,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-06-05 19:35+0200\n"
-"PO-Revision-Date: 2016-07-27 22:38+\n"
+"PO-Revision-Date: 2016-07-27 23:01+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -58,7 +58,7 @@ msgstr "Palavra-passe"
 
 #: ../glade/persistencewindow.glade.h:9
 msgid "Read-Only?"
-msgstr "Só de leitura?"
+msgstr "Apenas leitura?"
 
 #: ../glade/persistencewindow.glade.h:10
 msgid "Wrong passphrase. Please try again."
@@ -82,7 +82,7 @@ msgstr "Passwords do not match"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/https_everywhere] Update translations for https_everywhere

2016-07-27 Thread translation
commit c761e803790479f4f03b15bbeb9aef4e5f3cd1b6
Author: Translation commit bot 
Date:   Wed Jul 27 23:15:29 2016 +

Update translations for https_everywhere
---
 pt/ssl-observatory.dtd | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/pt/ssl-observatory.dtd b/pt/ssl-observatory.dtd
index 6d844a9..57dd073 100644
--- a/pt/ssl-observatory.dtd
+++ b/pt/ssl-observatory.dtd
@@ -34,7 +34,7 @@ to turn it on?">-->
 
 
 
+"Verificar certificados utilizando o Tor para anonimato (requer o Tor)">
 
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/torcheck_completed] Update translations for torcheck_completed

2016-07-27 Thread translation
commit 0ecedda762573ce25343afb7fb39eedaf38da9df
Author: Translation commit bot 
Date:   Wed Jul 27 23:15:18 2016 +

Update translations for torcheck_completed
---
 pt/torcheck.po | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/pt/torcheck.po b/pt/torcheck.po
index 2acaf05..0c5e89b 100644
--- a/pt/torcheck.po
+++ b/pt/torcheck.po
@@ -18,7 +18,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "POT-Creation-Date: 2012-02-16 20:28+PDT\n"
-"PO-Revision-Date: 2016-07-20 22:14+\n"
+"PO-Revision-Date: 2016-07-27 23:09+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -64,7 +64,7 @@ msgid ""
 msgstr "Uma falha de serviço temporária impede-nos de determinar se o seu 
endereço IP é um nó https://www.torproject.org/\;>Tor."
 
 msgid "Your IP address appears to be: "
-msgstr "O seu endereço IP aparenta ser: "
+msgstr "O seu endereço IP aparenta ser:"
 
 msgid "Are you using Tor?"
 msgstr "Está a utilizar o Tor?"
@@ -81,7 +81,7 @@ msgid ""
 msgstr "O Projeto Tor é uma organização sem fins lucrativos US 501(c)(3) 
dedicada à investigação, desenvolvimento e promoção de anonimidade e 
privacidade na web."
 
 msgid "Learn More "
-msgstr "Saiba mais "
+msgstr "Saber mais "
 
 msgid "Go"
 msgstr "Ir"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/torcheck] Update translations for torcheck

2016-07-27 Thread translation
commit 8759f8a5c2ce84236ee53fbed9a1ac76b81fc971
Author: Translation commit bot 
Date:   Wed Jul 27 23:15:15 2016 +

Update translations for torcheck
---
 pt/torcheck.po | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/pt/torcheck.po b/pt/torcheck.po
index 2acaf05..0c5e89b 100644
--- a/pt/torcheck.po
+++ b/pt/torcheck.po
@@ -18,7 +18,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "POT-Creation-Date: 2012-02-16 20:28+PDT\n"
-"PO-Revision-Date: 2016-07-20 22:14+\n"
+"PO-Revision-Date: 2016-07-27 23:09+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -64,7 +64,7 @@ msgid ""
 msgstr "Uma falha de serviço temporária impede-nos de determinar se o seu 
endereço IP é um nó https://www.torproject.org/\;>Tor."
 
 msgid "Your IP address appears to be: "
-msgstr "O seu endereço IP aparenta ser: "
+msgstr "O seu endereço IP aparenta ser:"
 
 msgid "Are you using Tor?"
 msgstr "Está a utilizar o Tor?"
@@ -81,7 +81,7 @@ msgid ""
 msgstr "O Projeto Tor é uma organização sem fins lucrativos US 501(c)(3) 
dedicada à investigação, desenvolvimento e promoção de anonimidade e 
privacidade na web."
 
 msgid "Learn More "
-msgstr "Saiba mais "
+msgstr "Saber mais "
 
 msgid "Go"
 msgstr "Ir"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-openpgp-applet] Update translations for tails-openpgp-applet

2016-07-27 Thread translation
commit 9320bdb87e6aaf773a017e8569ab832f163f5f41
Author: Translation commit bot 
Date:   Wed Jul 27 22:49:09 2016 +

Update translations for tails-openpgp-applet
---
 pt/openpgp-applet.pot | 22 +++---
 1 file changed, 11 insertions(+), 11 deletions(-)

diff --git a/pt/openpgp-applet.pot b/pt/openpgp-applet.pot
index 7034dbb..75b60b9 100644
--- a/pt/openpgp-applet.pot
+++ b/pt/openpgp-applet.pot
@@ -10,7 +10,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: ta...@boum.org\n"
 "POT-Creation-Date: 2015-08-10 15:55+0200\n"
-"PO-Revision-Date: 2016-07-20 22:23+\n"
+"PO-Revision-Date: 2016-07-27 22:48+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -21,7 +21,7 @@ msgstr ""
 
 #: bin/openpgp-applet:163
 msgid "You are about to exit OpenPGP Applet. Are you sure?"
-msgstr "Esta prestes a sair do OpenPGP Applet. Pretende proseguir?"
+msgstr "Esta prestes a sair do OpenPGP Applet. Continuar?"
 
 #: bin/openpgp-applet:175
 msgid "OpenPGP encryption applet"
@@ -29,39 +29,39 @@ msgstr "Miniaplicativo de criptografia OpenPGP"
 
 #: bin/openpgp-applet:178
 msgid "Exit"
-msgstr "Fechar"
+msgstr "Sair"
 
 #: bin/openpgp-applet:180
 msgid "About"
-msgstr "Informações"
+msgstr "Acerca"
 
 #: bin/openpgp-applet:235
 msgid "Encrypt Clipboard with _Passphrase"
-msgstr "Encriptar o Clipboard com _Passphrase"
+msgstr "Encriptar o Clipboard com _palavra-passe"
 
 #: bin/openpgp-applet:238
 msgid "Sign/Encrypt Clipboard with Public _Keys"
-msgstr "Assinar/Encriptar área de transferência com Public _Keys"
+msgstr "Assinar/encriptar área de transferência chaves públicas"
 
 #: bin/openpgp-applet:243
 msgid "_Decrypt/Verify Clipboard"
-msgstr "_Desencriptar/Verificar área de transferência"
+msgstr "_Decifrar/verificar área de transferência"
 
 #: bin/openpgp-applet:247
 msgid "_Manage Keys"
-msgstr "_Gerir Chaves"
+msgstr "_Gerir chaves"
 
 #: bin/openpgp-applet:251
 msgid "_Open Text Editor"
-msgstr "_Open Editor de Texto"
+msgstr "Abrir edit_or de texto"
 
 #: bin/openpgp-applet:295
 msgid "The clipboard does not contain valid input data."
-msgstr "A área de transferência não contém dados de entrada válidos."
+msgstr "A área de transferência não contém dados válidos."
 
 #: bin/openpgp-applet:347 bin/openpgp-applet:349 bin/openpgp-applet:351
 msgid "Unknown Trust"
-msgstr "Fidedignidade Desconhecida"
+msgstr "Fidedignidade desconhecida"
 
 #: bin/openpgp-applet:353
 msgid "Marginal Trust"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor-messenger-prefsdtd] Update translations for tor-messenger-prefsdtd

2016-07-27 Thread translation
commit 08eb462e16da1266f56f337dabb175263b5c2e77
Author: Translation commit bot 
Date:   Wed Jul 27 22:48:53 2016 +

Update translations for tor-messenger-prefsdtd
---
 pt/prefs.dtd | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/pt/prefs.dtd b/pt/prefs.dtd
index 671c462..05000c3 100644
--- a/pt/prefs.dtd
+++ b/pt/prefs.dtd
@@ -7,7 +7,7 @@
 
 
 
-
+
 
 
 
\ No newline at end of file

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-iuk] Update translations for tails-iuk

2016-07-27 Thread translation
commit f04e9a8d3b10a70dd0980194b3ab8eb05eb6ae65
Author: Translation commit bot 
Date:   Wed Jul 27 22:47:06 2016 +

Update translations for tails-iuk
---
 pt.po | 18 +-
 1 file changed, 9 insertions(+), 9 deletions(-)

diff --git a/pt.po b/pt.po
index dd061e1..a887932 100644
--- a/pt.po
+++ b/pt.po
@@ -15,7 +15,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: Tails developers \n"
 "POT-Creation-Date: 2016-05-25 16:55+0200\n"
-"PO-Revision-Date: 2016-07-20 22:23+\n"
+"PO-Revision-Date: 2016-07-27 22:41+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -115,7 +115,7 @@ msgid ""
 "Download size: %{size}s\n"
 "\n"
 "Do you want to upgrade now?"
-msgstr "Deve atualizar para %{name}s %{version}s.\n\nPara mais 
informação acerca desta nova versão vá a %{details_url}s\n\nÉ recomendado 
que feche todas as aplicações abertas durante a atualização.\nA 
transferência da atualização pode demorar algum tempo, desde alguns minutos 
até algumas horas.\nA rede será desativada após o término da transferência 
da atualização.\n\nTamanho da transferência: %{size}s\n\nDeseja atualizar 
agora?"
+msgstr "Deve atualizar para o %{name}s %{version}s.\n\nPara mais 
informação acerca desta nova versão, aceda a %{details_url}s\n\nrecomenda-se 
que feche todas as aplicações abertas durante a atualização.\nA descarga da 
atualização pode demorar algum tempo, desde alguns minutos até algumas 
horas.\nA rede será desativada após terminar de descarregar a 
atualização.\n\nTamanho do ficheiro: %{size}s\n\nDeseja atualizar agora?"
 
 #: ../lib/Tails/IUK/Frontend.pm:386
 msgid "Upgrade available"
@@ -147,12 +147,12 @@ msgstr "Disponível nova versão"
 
 #: ../lib/Tails/IUK/Frontend.pm:469
 msgid "Downloading upgrade"
-msgstr "A transferir a atualização"
+msgstr "A descarregar atualização"
 
 #: ../lib/Tails/IUK/Frontend.pm:472
 #, perl-brace-format
 msgid "Downloading the upgrade to %{name}s %{version}s..."
-msgstr "A transferir a atualização para %{name}s %{version}s ..."
+msgstr "A descarregar a atualização para %{name}s %{version}s ..."
 
 #: ../lib/Tails/IUK/Frontend.pm:513
 msgid ""
@@ -164,7 +164,7 @@ msgstr "Não foi possível transferir a 
atualização.\\n\\nVerifique a s
 
 #: ../lib/Tails/IUK/Frontend.pm:529 ../lib/Tails/IUK/Frontend.pm:548
 msgid "Error while downloading the upgrade"
-msgstr "Ocorreu um erro durante a transferência da atualização"
+msgstr "Ocorreu um erro ao descarregar a atualização"
 
 #: ../lib/Tails/IUK/Frontend.pm:541
 #, perl-brace-format
@@ -175,11 +175,11 @@ msgstr "O ficheiro de saída file '%{output_file}s' não 
existe, mas o tails-iuk
 
 #: ../lib/Tails/IUK/Frontend.pm:560
 msgid "Error while creating temporary downloading directory"
-msgstr "Erro ao criar a pasta temporária de transferência"
+msgstr "Erro ao criar a pasta temporária da descarga"
 
 #: ../lib/Tails/IUK/Frontend.pm:563
 msgid "Failed to create temporary download directory"
-msgstr "Falha ao criar pasta temporária de transferência"
+msgstr "Falha ao criar a pasta temporária da descarga"
 
 #: ../lib/Tails/IUK/Frontend.pm:587
 msgid ""
@@ -224,11 +224,11 @@ msgstr "Não foi possível reiniciar o sistema"
 
 #: ../lib/Tails/IUK/Frontend.pm:644
 msgid "Error while shutting down the network"
-msgstr "Ocorreu um erro enquanto encerrava a rede"
+msgstr "Ocorreu um erro ao dsligar a rede"
 
 #: ../lib/Tails/IUK/Frontend.pm:647
 msgid "Failed to shutdown network"
-msgstr "Não foi possível encerrar a rede"
+msgstr "Não foi possível desligar a rede"
 
 #: ../lib/Tails/IUK/Frontend.pm:657
 msgid "Upgrading the system"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor_animation_completed] Update translations for tor_animation_completed

2016-07-27 Thread translation
commit 3cec366214b6aeccf9a50444784273e5a96c7010
Author: Translation commit bot 
Date:   Wed Jul 27 22:47:38 2016 +

Update translations for tor_animation_completed
---
 pt.srt | 8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/pt.srt b/pt.srt
index 1d4b6f7..b57b367 100644
--- a/pt.srt
+++ b/pt.srt
@@ -36,8 +36,8 @@ que utilizou para navegar na Web,
 
 9
 00:00:26,700 --> 00:00:29,140
-dhe shumë më shumë informacion
-për ju dhe jetën tuaj
+e muitas mais informações
+sobre si e sobre a sua vida
 
 10
 00:00:29,200 --> 00:00:31,500
@@ -147,7 +147,7 @@ a não ser que inicie a sessão e lhes diga.
 
 32
 00:01:54,200 --> 00:01:55,840
-Duke shkarkuar dhe përdorur Tor,
+Ao descarregar e utilizar o Tor,
 
 33
 00:01:56,200 --> 00:01:58,560
@@ -160,5 +160,5 @@ si aktivistët, gazetarët dhe blogerët.
 
 35
 00:02:02,000 --> 00:02:07,000
-Transfira e utilize o Tor! Ou execute um retransmissor.
+Descarregue e utilize o Tor! Ou execute um retransmissor.
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor_animation] Update translations for tor_animation

2016-07-27 Thread translation
commit b9578395b17371cbb5b547afdaba4568269240f9
Author: Translation commit bot 
Date:   Wed Jul 27 22:47:24 2016 +

Update translations for tor_animation
---
 pt.srt | 8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/pt.srt b/pt.srt
index 1d4b6f7..b57b367 100644
--- a/pt.srt
+++ b/pt.srt
@@ -36,8 +36,8 @@ que utilizou para navegar na Web,
 
 9
 00:00:26,700 --> 00:00:29,140
-dhe shumë më shumë informacion
-për ju dhe jetën tuaj
+e muitas mais informações
+sobre si e sobre a sua vida
 
 10
 00:00:29,200 --> 00:00:31,500
@@ -147,7 +147,7 @@ a não ser que inicie a sessão e lhes diga.
 
 32
 00:01:54,200 --> 00:01:55,840
-Duke shkarkuar dhe përdorur Tor,
+Ao descarregar e utilizar o Tor,
 
 33
 00:01:56,200 --> 00:01:58,560
@@ -160,5 +160,5 @@ si aktivistët, gazetarët dhe blogerët.
 
 35
 00:02:02,000 --> 00:02:07,000
-Transfira e utilize o Tor! Ou execute um retransmissor.
+Descarregue e utilize o Tor! Ou execute um retransmissor.
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-misc] Update translations for tails-misc

2016-07-27 Thread translation
commit 03fba697fef4c8920228f885d9e602b1e179947a
Author: Translation commit bot 
Date:   Wed Jul 27 22:46:37 2016 +

Update translations for tails-misc
---
 pt.po | 12 ++--
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/pt.po b/pt.po
index 3f7eea3..d4bf591 100644
--- a/pt.po
+++ b/pt.po
@@ -22,7 +22,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-06-06 14:26+0200\n"
-"PO-Revision-Date: 2016-07-20 22:24+\n"
+"PO-Revision-Date: 2016-07-27 22:46+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -65,7 +65,7 @@ msgid ""
 "When you reboot Tails, all of Electrum's data will be lost, including your "
 "Bitcoin wallet. It is strongly recommended to only run Electrum when its "
 "persistence feature is activated."
-msgstr "Quando reinicia o Tails, todos os dados do Electrum serão perdidos, 
incluindo a sua carteira Bitcoin. É altamente recomendado que só execute o 
Electrum quando a sua funcionalidade de persistência esteja ativa."
+msgstr "Ao reiniciar o Tails, todos os dados do Electrum serão perdidos, 
incluindo a sua carteira Bitcoin. Recomenda-se que apenas execute o Electrum se 
a funcionalidade de persistência estiver ativa."
 
 #: config/chroot_local-includes/usr/local/bin/electrum:21
 msgid "Do you want to start Electrum anyway?"
@@ -75,7 +75,7 @@ msgstr "Mesmo assim, deseja iniciar o Electrum?"
 #: config/chroot_local-includes/usr/local/bin/icedove:37
 #: config/chroot_local-includes/usr/local/sbin/unsafe-browser:41
 msgid "_Launch"
-msgstr "_Lançar"
+msgstr "_Iniciar"
 
 #: config/chroot_local-includes/usr/local/bin/electrum:24
 #: config/chroot_local-includes/usr/local/bin/icedove:38
@@ -85,7 +85,7 @@ msgstr "_Sair"
 
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:136
 msgid "OpenPGP encryption applet"
-msgstr "Miniaplicativo de criptografia OpenPGP"
+msgstr "Miniaplicativo de cifra OpenPGP"
 
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:139
 msgid "Exit"
@@ -440,13 +440,13 @@ msgstr "Isto pode demorar um pouco, por favor seja 
paciente."
 
 #: config/chroot_local-includes/usr/local/sbin/unsafe-browser:57
 msgid "Shutting down the Unsafe Browser..."
-msgstr "A encerrar o Navegador Inseguro."
+msgstr "A encerrar o navegador inseguro..."
 
 #: config/chroot_local-includes/usr/local/sbin/unsafe-browser:58
 msgid ""
 "This may take a while, and you may not restart the Unsafe Browser until it "
 "is properly shut down."
-msgstr "Isto pode demorar um pouco, e você não deve reiniciar o Navegador 
Inseguro até que ele tenha sido propriamente desligado."
+msgstr "Isto pode demorar um pouco e você não deve reiniciar o navegador 
inseguro até que este tenha sido propriamente desligado."
 
 #: config/chroot_local-includes/usr/local/sbin/unsafe-browser:70
 msgid "Failed to restart Tor."

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/torbutton-torbuttonproperties] Update translations for torbutton-torbuttonproperties

2016-07-27 Thread translation
commit 309200e8307144b9a5fd78ab4be9aa606f582171
Author: Translation commit bot 
Date:   Wed Jul 27 22:46:59 2016 +

Update translations for torbutton-torbuttonproperties
---
 pt/torbutton.properties | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pt/torbutton.properties b/pt/torbutton.properties
index e44eadd..d6bde9d 100644
--- a/pt/torbutton.properties
+++ b/pt/torbutton.properties
@@ -29,10 +29,10 @@ torbutton.popup.pref_error = O Torbutton não consegue 
atualizar as preferência
 torbutton.popup.permission_denied = Por favor, reinicie as permissões da 
diretoria do Navegador Tor ou copie-a para uma nova localização.
 torbutton.popup.device_full = O disco parece estar cheio. Por favor, liberte 
espaço ou mova o Navegador Tor para um novo dispositivo.
 torbutton.title.prompt_torbrowser = Informação Importante do Torbutton
-torbutton.popup.prompt_torbrowser = O Torbutton funciona agora de forma 
diferente: já não pode desligá-lo.\n\nProcedemos a esta alteração porque 
não é seguro usar o Torbutton num explorador também usado para buscas fora 
do Tor. Havia demasiados erros que não conseguimos corrigir de outra 
forma.\n\nSe pretende continuar a usar o Firefox normalmente, deve desinstalar 
o Torbutton e carregar o Tor Browser Bundle para o seu computador. As 
políticas de privacidade do Explorador do Tor também são superiores às 
normais no Firefox, mesmo quando este é usado com o Torbutton.\n\nPara remover 
o Torbutton abra Ferramentas->Acessórios->Extensões e clique no botão 
Remover junto ao Torbutton.
+torbutton.popup.prompt_torbrowser = O Torbutton funciona agora de forma 
diferente: já não o poderá desligar.\n\nEfetuámos alteração porque não 
é seguro usar o Torbutton num navegador também usado para navegação não 
Tor. Havia demasiados erros que não conseguiríamos corrigir de outra 
forma.\n\nSe pretende continuar a usar o Firefox, deve desinstalar o Torbutton 
e descarregar o Tor Browser Bundle para o seu computador. As políticas de 
privacidade do Navegador Tor também são superiores às normais no Firefox, 
mesmo quando este é usado com o Torbutton.\n\nPara remover o Torbutton, aceda 
a Ferramentas->Acessórios->Extensões e clique no botão Remover junto ao 
Torbutton.
 torbutton.popup.short_torbrowser = Informação importante do Torbutton!\nO 
Torbutton não está sempre activo.\nClique no Torbutton para mais informação.
 
-torbutton.popup.confirm_plugins = Plugins such as Flash can harm your privacy 
and anonymity.\n\nThey can also bypass Tor to reveal your current location and 
IP address.\n\nAre you sure you want to enable plugins?\n\n
+torbutton.popup.confirm_plugins = Os plugins tais como o Flash podem invadir a 
sua privacidade.\n\nTambém podem originar que o Tor revele a sua localização 
e o seu endereço IP.\n\nTem a certeza de que deseja ativar os plugins?\n\n
 torbutton.popup.never_ask_again = Não voltar a perguntar-me
 torbutton.popup.confirm_newnym = O Navegador Tor irá fechar todas as janela e 
separadores. Estarão perdidas todas sessões do sítio da Web.\n\nReiniciar o 
Navegador Tor para repor a sua identidade?\n\n
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/liveusb-creator] Update translations for liveusb-creator

2016-07-27 Thread translation
commit 647cb86cfc77ac2226f36ee8ed0d528caae6db12
Author: Translation commit bot 
Date:   Wed Jul 27 22:45:47 2016 +

Update translations for liveusb-creator
---
 pt/pt.po | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/pt/pt.po b/pt/pt.po
index 919fc4b..bc65983 100644
--- a/pt/pt.po
+++ b/pt/pt.po
@@ -20,7 +20,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2015-11-02 21:23+0100\n"
-"PO-Revision-Date: 2016-07-20 22:12+\n"
+"PO-Revision-Date: 2016-07-27 22:35+\n"
 "Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
@@ -385,7 +385,7 @@ msgid ""
 "This button allows you to browse for an existing Live system ISO that you "
 "have previously downloaded.  If you do not select one, a release will be "
 "downloaded for you automatically."
-msgstr "Este botão permite-lhe procurar uma versão da ISO do sistema Live, 
previamente descarregada. Se não selecionar uma versão a versão selecionada 
será descarregada."
+msgstr "Este botão permite-lhe procurar uma versão da ISO do sistema Live, 
previamente descarregada. Se não selecionar uma versão, a versão selecionada 
será descarregada."
 
 #: ../liveusb/dialog.py:171
 msgid ""
@@ -608,7 +608,7 @@ msgstr "Está a utilizar uma versão antiga do 
syslinux-extlinux que não suport
 
 #: ../liveusb/gui.py:783
 msgid "You can try again to resume your download"
-msgstr "Pode tentar de novo para retomar a sua transferência"
+msgstr "Pode tentar retomar a sua descarga"
 
 #: ../liveusb/creator.py:95
 msgid "You must run this application as root"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-greeter] Update translations for tails-greeter

2016-07-27 Thread translation
commit 5c299e25f2b0ad89566d65de62ad565f0d18003c
Author: Translation commit bot 
Date:   Wed Jul 27 22:46:01 2016 +

Update translations for tails-greeter
---
 pt/pt.po | 11 ++-
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/pt/pt.po b/pt/pt.po
index a91c8d5..dca8257 100644
--- a/pt/pt.po
+++ b/pt/pt.po
@@ -8,14 +8,15 @@
 # testsubject67 , 2014
 # Lídia Martins , 2015
 # alfalb_mansil, 2014
-# Manuela Silva , 2015
+# Manuela Silva , 2015
+# Sérgio Marques , 2016
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2016-02-29 14:32+0100\n"
-"PO-Revision-Date: 2016-03-21 16:27+\n"
-"Last-Translator: carolyn \n"
+"POT-Creation-Date: 2016-06-05 19:35+0200\n"
+"PO-Revision-Date: 2016-07-27 22:38+\n"
+"Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -109,7 +110,7 @@ msgstr "Documen
 msgid ""
 "Spoofing MAC addresses hides the serial number of your network cards to the "
 "local networks. This can help you hide your geographical location."
-msgstr "O roubo de identidade MAC esconde o número de série das placas de 
rede às redes locais. Isto pode ajudar a ocultar a sua localização 
geográfica."
+msgstr "O roubo de identidade MAC oculta o número de série das placas de 
rede às redes locais. Isto pode ajudar a ocultar a sua localização 
geográfica."
 
 #: ../glade/optionswindow.glade.h:13
 msgid ""

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-persistence-setup_completed] Update translations for tails-persistence-setup_completed

2016-07-27 Thread translation
commit 3e0bd1347b0b3feb855d8dee4aa456784d61912f
Author: Translation commit bot 
Date:   Wed Jul 27 22:45:57 2016 +

Update translations for tails-persistence-setup_completed
---
 pt/pt.po | 9 +
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/pt/pt.po b/pt/pt.po
index 1540244..ec7e0a9 100644
--- a/pt/pt.po
+++ b/pt/pt.po
@@ -13,14 +13,15 @@
 # Nizia Dantas , 2014
 # Andrew Melim , 2014
 # Pedro Albuquerque , 2014
+# Sérgio Marques , 2016
 # sccosta , 2014
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: Tails developers \n"
 "POT-Creation-Date: 2016-05-25 02:27+0200\n"
-"PO-Revision-Date: 2016-06-06 08:15+\n"
-"Last-Translator: carolyn \n"
+"PO-Revision-Date: 2016-07-27 22:45+\n"
+"Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -42,7 +43,7 @@ msgstr "GnuPG"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:60
 msgid "GnuPG keyrings and configuration"
-msgstr "Configuração e Keyrings do GnuPG"
+msgstr "Configuração e chaveiro GnuPG"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:68
 msgid "SSH Client"
@@ -58,7 +59,7 @@ msgstr "Pidgin"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:80
 msgid "Pidgin profiles and OTR keyring"
-msgstr "Perfis Pidgin e keyrings OTR"
+msgstr "Perfis Pidgin e chaveiro OTR"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:88
 msgid "Icedove"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor-launcher-progress_completed] Update translations for tor-launcher-progress_completed

2016-07-27 Thread translation
commit 4f9c4491811be4d8b3b522d17995861b445acde1
Author: Translation commit bot 
Date:   Wed Jul 27 22:46:28 2016 +

Update translations for tor-launcher-progress_completed
---
 pt/progress.dtd | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/pt/progress.dtd b/pt/progress.dtd
index a75fd41..6ed4a63 100644
--- a/pt/progress.dtd
+++ b/pt/progress.dtd
@@ -1,4 +1,4 @@
 
 
 
-
+

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor-launcher-progress] Update translations for tor-launcher-progress

2016-07-27 Thread translation
commit b705f2392b6a70ff882b9cf3cb11f76901756451
Author: Translation commit bot 
Date:   Wed Jul 27 22:46:25 2016 +

Update translations for tor-launcher-progress
---
 pt/progress.dtd | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/pt/progress.dtd b/pt/progress.dtd
index a75fd41..6ed4a63 100644
--- a/pt/progress.dtd
+++ b/pt/progress.dtd
@@ -1,4 +1,4 @@
 
 
 
-
+

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-greeter_completed] Update translations for tails-greeter_completed

2016-07-27 Thread translation
commit 0e00dc4a3718f3d4012f5c9fb024a35cf3a45c93
Author: Translation commit bot 
Date:   Wed Jul 27 22:46:04 2016 +

Update translations for tails-greeter_completed
---
 pt/pt.po | 11 ++-
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/pt/pt.po b/pt/pt.po
index a91c8d5..dca8257 100644
--- a/pt/pt.po
+++ b/pt/pt.po
@@ -8,14 +8,15 @@
 # testsubject67 , 2014
 # Lídia Martins , 2015
 # alfalb_mansil, 2014
-# Manuela Silva , 2015
+# Manuela Silva , 2015
+# Sérgio Marques , 2016
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2016-02-29 14:32+0100\n"
-"PO-Revision-Date: 2016-03-21 16:27+\n"
-"Last-Translator: carolyn \n"
+"POT-Creation-Date: 2016-06-05 19:35+0200\n"
+"PO-Revision-Date: 2016-07-27 22:38+\n"
+"Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -109,7 +110,7 @@ msgstr "Documen
 msgid ""
 "Spoofing MAC addresses hides the serial number of your network cards to the "
 "local networks. This can help you hide your geographical location."
-msgstr "O roubo de identidade MAC esconde o número de série das placas de 
rede às redes locais. Isto pode ajudar a ocultar a sua localização 
geográfica."
+msgstr "O roubo de identidade MAC oculta o número de série das placas de 
rede às redes locais. Isto pode ajudar a ocultar a sua localização 
geográfica."
 
 #: ../glade/optionswindow.glade.h:13
 msgid ""

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-persistence-setup] Update translations for tails-persistence-setup

2016-07-27 Thread translation
commit 0e05f5244e71e000648f4fece3f6b50e66559246
Author: Translation commit bot 
Date:   Wed Jul 27 22:45:53 2016 +

Update translations for tails-persistence-setup
---
 pt/pt.po | 9 +
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/pt/pt.po b/pt/pt.po
index 1540244..ec7e0a9 100644
--- a/pt/pt.po
+++ b/pt/pt.po
@@ -13,14 +13,15 @@
 # Nizia Dantas , 2014
 # Andrew Melim , 2014
 # Pedro Albuquerque , 2014
+# Sérgio Marques , 2016
 # sccosta , 2014
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: Tails developers \n"
 "POT-Creation-Date: 2016-05-25 02:27+0200\n"
-"PO-Revision-Date: 2016-06-06 08:15+\n"
-"Last-Translator: carolyn \n"
+"PO-Revision-Date: 2016-07-27 22:45+\n"
+"Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -42,7 +43,7 @@ msgstr "GnuPG"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:60
 msgid "GnuPG keyrings and configuration"
-msgstr "Configuração e Keyrings do GnuPG"
+msgstr "Configuração e chaveiro GnuPG"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:68
 msgid "SSH Client"
@@ -58,7 +59,7 @@ msgstr "Pidgin"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:80
 msgid "Pidgin profiles and OTR keyring"
-msgstr "Perfis Pidgin e keyrings OTR"
+msgstr "Perfis Pidgin e chaveiro OTR"
 
 #: ../lib/Tails/Persistence/Configuration/Presets.pm:88
 msgid "Icedove"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb] Update translations for bridgedb

2016-07-27 Thread translation
commit 056476b81df2b7a3b1ff414c962db39c44d3aa11
Author: Translation commit bot 
Date:   Wed Jul 27 22:45:06 2016 +

Update translations for bridgedb
---
 pt/LC_MESSAGES/bridgedb.po | 20 ++--
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/pt/LC_MESSAGES/bridgedb.po b/pt/LC_MESSAGES/bridgedb.po
index fa7d72d..48bcebf 100644
--- a/pt/LC_MESSAGES/bridgedb.po
+++ b/pt/LC_MESSAGES/bridgedb.po
@@ -8,21 +8,21 @@
 # André Monteiro , 2014
 # Bruno D. Rodrigues , 2015
 # kagazz , 2014
-# Manuela Silva , 2015
+# Manuela Silva , 2015
 # alfalb_mansil, 2014
-# Manuela Silva , 2015
-# Manuela Silva , 2015
+# Manuela Silva , 2015
+# Manuela Silva , 2015
 # Andrew Melim , 2014
 # Pedro Albuquerque , 2014-2015
-# Sérgio Marques , 2014
+# Sérgio Marques , 2014,2016
 # TiagoJMMC , 2014
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDB=bridgedb-reported,msgid=isis,sysrqb=isis'\n"
 "POT-Creation-Date: 2015-07-25 03:40+\n"
-"PO-Revision-Date: 2016-03-21 16:27+\n"
-"Last-Translator: Bruno D. Rodrigues \n"
+"PO-Revision-Date: 2016-07-27 22:39+\n"
+"Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -112,7 +112,7 @@ msgstr "Passo %s1%s"
 #: bridgedb/https/templates/index.html:13
 #, python-format
 msgid "Download %s Tor Browser %s"
-msgstr "Transferir o %s Navegador Tor %s"
+msgstr "Descarregar o %s navegador Tor %s"
 
 #: bridgedb/https/templates/index.html:25
 #, python-format
@@ -132,7 +132,7 @@ msgstr "Passo %s3%s"
 #: bridgedb/https/templates/index.html:38
 #, python-format
 msgid "Now %s add the bridges to Tor Browser %s"
-msgstr "Agora, %s adicione as pontes ao Navegador Tor %s"
+msgstr "Agora, %s adicione as pontes ao navegador Tor %s"
 
 #. TRANSLATORS: Please make sure the '%s' surrounding single letters at the
 #. beginning of words are present in your final translation. Thanks!
@@ -184,7 +184,7 @@ msgstr "Aqui estão as suas pontes:"
 msgid ""
 "You have exceeded the rate limit. Please slow down! The minimum time 
between\n"
 "emails is %s hours. All further emails during this time period will be 
ignored."
-msgstr "Você excedeu a taxa limite. Por favor, abrande! O tempo mínimo entre 
e-mails é de %s horas. Todas os e-mails seguintes durante este período serão 
ignoradas."
+msgstr "Você excedeu a taxa limite. Por favor, abrande! O tempo mínimo entre 
e-mails é de %s horas. Todos os e-mails seguintes durante este período serão 
ignorados."
 
 #: bridgedb/strings.py:50
 msgid ""
@@ -341,7 +341,7 @@ msgid ""
 "To enter bridges into Tor Browser, first go to the %s Tor Browser download\n"
 "page %s and then follow the instructions there for downloading and starting\n"
 "Tor Browser."
-msgstr "Para inserir as ligações no Navegador Tor, vá primeiro a %s - 
transferir navegado Tor\npágina %s e depois siga as instruções para 
transferir e iniciar o \nNavegador Tor."
+msgstr "Para inserir as ligações no navegador Tor, aceda à %s - página 
para descarregar o Tor %s\ne siga as instruções sobre com descarregar e 
utilizar o navegador Tor."
 
 #. TRANSLATORS: Please DO NOT translate "Tor".
 #: bridgedb/strings.py:151

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb_completed] Update translations for bridgedb_completed

2016-07-27 Thread translation
commit f538830b6e06314ad3a4d19003574c3dfa357876
Author: Translation commit bot 
Date:   Wed Jul 27 22:45:16 2016 +

Update translations for bridgedb_completed
---
 pt/LC_MESSAGES/bridgedb.po | 20 ++--
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/pt/LC_MESSAGES/bridgedb.po b/pt/LC_MESSAGES/bridgedb.po
index fa7d72d..48bcebf 100644
--- a/pt/LC_MESSAGES/bridgedb.po
+++ b/pt/LC_MESSAGES/bridgedb.po
@@ -8,21 +8,21 @@
 # André Monteiro , 2014
 # Bruno D. Rodrigues , 2015
 # kagazz , 2014
-# Manuela Silva , 2015
+# Manuela Silva , 2015
 # alfalb_mansil, 2014
-# Manuela Silva , 2015
-# Manuela Silva , 2015
+# Manuela Silva , 2015
+# Manuela Silva , 2015
 # Andrew Melim , 2014
 # Pedro Albuquerque , 2014-2015
-# Sérgio Marques , 2014
+# Sérgio Marques , 2014,2016
 # TiagoJMMC , 2014
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDB=bridgedb-reported,msgid=isis,sysrqb=isis'\n"
 "POT-Creation-Date: 2015-07-25 03:40+\n"
-"PO-Revision-Date: 2016-03-21 16:27+\n"
-"Last-Translator: Bruno D. Rodrigues \n"
+"PO-Revision-Date: 2016-07-27 22:39+\n"
+"Last-Translator: Sérgio Marques \n"
 "Language-Team: Portuguese 
(http://www.transifex.com/otf/torproject/language/pt/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -112,7 +112,7 @@ msgstr "Passo %s1%s"
 #: bridgedb/https/templates/index.html:13
 #, python-format
 msgid "Download %s Tor Browser %s"
-msgstr "Transferir o %s Navegador Tor %s"
+msgstr "Descarregar o %s navegador Tor %s"
 
 #: bridgedb/https/templates/index.html:25
 #, python-format
@@ -132,7 +132,7 @@ msgstr "Passo %s3%s"
 #: bridgedb/https/templates/index.html:38
 #, python-format
 msgid "Now %s add the bridges to Tor Browser %s"
-msgstr "Agora, %s adicione as pontes ao Navegador Tor %s"
+msgstr "Agora, %s adicione as pontes ao navegador Tor %s"
 
 #. TRANSLATORS: Please make sure the '%s' surrounding single letters at the
 #. beginning of words are present in your final translation. Thanks!
@@ -184,7 +184,7 @@ msgstr "Aqui estão as suas pontes:"
 msgid ""
 "You have exceeded the rate limit. Please slow down! The minimum time 
between\n"
 "emails is %s hours. All further emails during this time period will be 
ignored."
-msgstr "Você excedeu a taxa limite. Por favor, abrande! O tempo mínimo entre 
e-mails é de %s horas. Todas os e-mails seguintes durante este período serão 
ignoradas."
+msgstr "Você excedeu a taxa limite. Por favor, abrande! O tempo mínimo entre 
e-mails é de %s horas. Todos os e-mails seguintes durante este período serão 
ignorados."
 
 #: bridgedb/strings.py:50
 msgid ""
@@ -341,7 +341,7 @@ msgid ""
 "To enter bridges into Tor Browser, first go to the %s Tor Browser download\n"
 "page %s and then follow the instructions there for downloading and starting\n"
 "Tor Browser."
-msgstr "Para inserir as ligações no Navegador Tor, vá primeiro a %s - 
transferir navegado Tor\npágina %s e depois siga as instruções para 
transferir e iniciar o \nNavegador Tor."
+msgstr "Para inserir as ligações no navegador Tor, aceda à %s - página 
para descarregar o Tor %s\ne siga as instruções sobre com descarregar e 
utilizar o navegador Tor."
 
 #. TRANSLATORS: Please DO NOT translate "Tor".
 #: bridgedb/strings.py:151

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb] Update translations for bridgedb

2016-07-27 Thread translation
commit 20d95d7ca932b53188b07f161d82e364e0a017a2
Author: Translation commit bot 
Date:   Wed Jul 27 13:15:05 2016 +

Update translations for bridgedb
---
 la/LC_MESSAGES/bridgedb.po | 14 +++---
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/la/LC_MESSAGES/bridgedb.po b/la/LC_MESSAGES/bridgedb.po
index 4c8f72c..b404342 100644
--- a/la/LC_MESSAGES/bridgedb.po
+++ b/la/LC_MESSAGES/bridgedb.po
@@ -10,7 +10,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDB=bridgedb-reported,msgid=isis,sysrqb=isis'\n"
 "POT-Creation-Date: 2015-07-25 03:40+\n"
-"PO-Revision-Date: 2016-07-27 12:39+\n"
+"PO-Revision-Date: 2016-07-27 13:04+\n"
 "Last-Translator: Alisa P \n"
 "Language-Team: Latin (http://www.transifex.com/otf/torproject/language/la/)\n"
 "MIME-Version: 1.0\n"
@@ -70,7 +70,7 @@ msgstr "QRCode pro lineis pontis tuis"
 #: bridgedb/https/templates/bridges.html:67
 #: bridgedb/https/templates/bridges.html:125
 msgid "Uh oh, spaghettios!"
-msgstr ""
+msgstr "False est!"
 
 #: bridgedb/https/templates/bridges.html:68
 msgid "It seems there was an error getting your QRCode."
@@ -211,7 +211,7 @@ msgstr "Claves publicae"
 msgid ""
 "This email was generated with rainbows, unicorns, and sparkles\n"
 "for %s on %s at %s."
-msgstr "Ea littera in linea arcibus et unicornibus et lucibus\npro %s tempore 
%s %s."
+msgstr "Eae litterae in linea arcibus et unicornibus et lucibus facti 
sunt\npro %s tempore %s %s."
 
 #. TRANSLATORS: Please DO NOT translate "BridgeDB".
 #. TRANSLATORS: Please DO NOT translate "Pluggable Transports".
@@ -247,7 +247,7 @@ msgid ""
 "Pluggable Transports %s which maybe doesn't sound as cool, but they can 
still\n"
 "help to circumvent internet censorship in many cases.\n"
 "\n"
-msgstr ""
+msgstr "Additione BridgeDB multi pontes simplices habet %s\nsine \"Pluggable 
thansports %s, quid fortasse non tam grave sonat, sed adhuc\ncircumventionem 
censurae coniunctionis computatorum adesse possunt.\n\n"
 
 #: bridgedb/strings.py:101
 msgid "What are bridges?"
@@ -256,11 +256,11 @@ msgstr "Quid sunt pontes?"
 #: bridgedb/strings.py:102
 #, python-format
 msgid "%s Bridges %s are Tor relays that help you circumvent censorship."
-msgstr ""
+msgstr "%s Pontes %s sunt Tor transmittores, quae tibi censuram circumvenire 
adsunt."
 
 #: bridgedb/strings.py:107
 msgid "I need an alternative way of getting bridges!"
-msgstr ""
+msgstr "Modum alium acquistionis pontum egeo!"
 
 #: bridgedb/strings.py:108
 #, python-format
@@ -268,7 +268,7 @@ msgid ""
 "Another way to get bridges is to send an email to %s. Please note that you 
must\n"
 "send the email using an address from one of the following email providers:\n"
 "%s, %s or %s."
-msgstr ""
+msgstr "Modus alius acquistionis pontum missio litterarum in linea ad %s 
est.\nLitteras in linea sententia loci de uno eius processoribus litterarum in 
linea esse debet:\n%s aut %s aut %s."
 
 #: bridgedb/strings.py:115
 msgid "My bridges don't work! I need help!"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb] Update translations for bridgedb

2016-07-27 Thread translation
commit b9ccc2eb975d2aa1166badb806623a773eee0b77
Author: Translation commit bot 
Date:   Wed Jul 27 12:45:04 2016 +

Update translations for bridgedb
---
 la/LC_MESSAGES/bridgedb.po | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/la/LC_MESSAGES/bridgedb.po b/la/LC_MESSAGES/bridgedb.po
index 17b3b49..4c8f72c 100644
--- a/la/LC_MESSAGES/bridgedb.po
+++ b/la/LC_MESSAGES/bridgedb.po
@@ -10,7 +10,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDB=bridgedb-reported,msgid=isis,sysrqb=isis'\n"
 "POT-Creation-Date: 2015-07-25 03:40+\n"
-"PO-Revision-Date: 2016-07-26 18:42+\n"
+"PO-Revision-Date: 2016-07-27 12:39+\n"
 "Last-Translator: Alisa P \n"
 "Language-Team: Latin (http://www.transifex.com/otf/torproject/language/la/)\n"
 "MIME-Version: 1.0\n"
@@ -233,7 +233,7 @@ msgid ""
 "Some bridges with IPv6 addresses are also available, though some Pluggable\n"
 "Transports aren't IPv6 compatible.\n"
 "\n"
-msgstr ""
+msgstr "Nonnulli pontes sententiis loci IPv6 etiam existunt, quamquam non omna 
\"Pluggable Transports\"\n cum IPv6 esse possunt.\n\n"
 
 #. TRANSLATORS: Please DO NOT translate "BridgeDB".
 #. TRANSLATORS: The phrase "plain-ol'-vanilla" means "plain, boring,

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [metrics-web/master] Add link pages to two of phw's image galleries.

2016-07-27 Thread karsten
commit 2421d9164476893a65f0703a0326389964d9ff94
Author: Karsten Loesing 
Date:   Wed Jul 13 16:09:44 2016 +0200

Add link pages to two of phw's image galleries.

Implements the first phase of #19183.
---
 website/etc/metrics.json|  28 
 website/etc/web.xml |   2 ++
 website/web/images/networkchurn.png | Bin 0 -> 98625 bytes
 website/web/images/uptimes.jpg  | Bin 0 -> 53484 bytes
 4 files changed, 30 insertions(+)

diff --git a/website/etc/metrics.json b/website/etc/metrics.json
index ffa2ad2..c4b47a7 100644
--- a/website/etc/metrics.json
+++ b/website/etc/metrics.json
@@ -889,5 +889,33 @@
 "related": [
   "relayflags"
 ]
+  },
+  {
+"id": "uptimes",
+"title": "Monthly uptime of relays",
+"tags": [
+  "Relays"
+],
+"type": "Link",
+"level": "Advanced",
+"description": "The following image illustrates the uptime of all known 
relays in a given month.  Each row of pixels 
denotes one consensus (that is, one hour), 
and each column denotes one relay.  Each pixel denotes if a given relay was 
online or offline at a given hour: black means online, white means offline, and 
red highlights relays with identical uptime patterns.  The complete image 
gallery can be found on https://nymity.ch/sybilhunting/uptime-visualisation/\;>Philipp Winter's 
homepage.https://nymity.ch/sybilhunting/uptime-visualisation/\;>",
+"related": [
+  "networkchurn"
+]
+  },
+  {
+"id": "networkchurn",
+"title": "Network churn rate by relay flag",
+"tags": [
+  "Relays"
+],
+"type": "Link",
+"level": "Advanced",
+"description": "The following image shows the churn rate of the Tor 
network by relay flag in a given month.  
The churn rate, a value in the interval [0,1], captures the rate of relays joining and leaving the network from one 
consensus to the next (that is, within one 
hour).  The complete image gallery can be found on https://nymity.ch/sybilhunting/churn-values/\;>Philipp Winter's 
homepage.https://nymity.ch/sybilhunting/churn-values/\;>",
+"related": [
+  "uptimes",
+  "networksize",
+  "relayflags"
+]
   }
 ]
diff --git a/website/etc/web.xml b/website/etc/web.xml
index b1b6511..ebd9876 100644
--- a/website/etc/web.xml
+++ b/website/etc/web.xml
@@ -91,6 +91,8 @@
 Link
 /oxford-anonymous-internet.html
 /uncharted-data-flow.html
+/uptimes.html
+/networkchurn.html
   
 
   
diff --git a/website/web/images/networkchurn.png 
b/website/web/images/networkchurn.png
new file mode 100644
index 000..027a8bf
Binary files /dev/null and b/website/web/images/networkchurn.png differ
diff --git a/website/web/images/uptimes.jpg b/website/web/images/uptimes.jpg
new file mode 100644
index 000..1376437
Binary files /dev/null and b/website/web/images/uptimes.jpg differ

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [onionoo/master] Removed Vagrant and added links to wiki guide docs.

2016-07-27 Thread karsten
commit d61c0ee7381789d0c71a9e5c3a3bbc5324026dbb
Author: iwakeh 
Date:   Mon Jul 25 22:39:20 2016 +0200

Removed Vagrant and added links to wiki guide docs.
---
 CONTRIB.md   | 90 ++--
 Vagrantfile  | 19 ---
 vagrant/bootstrap.sh | 30 --
 3 files changed, 3 insertions(+), 136 deletions(-)

diff --git a/CONTRIB.md b/CONTRIB.md
index d971ec4..a432069 100644
--- a/CONTRIB.md
+++ b/CONTRIB.md
@@ -1,92 +1,8 @@
 # Contributor Guide
 
-This guide is meant for people who want to contribute patches to Onionoo.
-It contains the following sections:
-
- - Patch format
- - Whitespace conventions
- - Vagrant-based development environment
- - Documentation overview
- - Versions
-
-## Patch format
-
-Format your patches using `git format-patch` if you want to submit just a
-single, small commit.
-If you want to submit more than one commit, push your changes to a public
-Git repository somewhere that can be pulled from.
-
-## Whitespace conventions
-
-Whitespace conventions are important, because whitespace changes bloat
-patches and make them harder to review.
-If we all agree on the same whitespace conventions, the only changes to
-review are actually meaningful changes.
-If you need to make whitespace changes, because files did not conform to
-whitespace conventions before, do these changes in one or more separate
-commits that contain nothing else than whitespace changes.
-
-The following whitespace conventions apply:
-
- - Maximum line width is 74 characters.  Why 74?  Because it looks pretty
-in vim in a 80-character terminal with line numbers turned on.
- - Full sentences are followed by a period and two spaces.  An exception
-to this rule are sentences in markup files like Markdown; in this case,
-each sentence should start with a newline, so that a change in one
-sentence doesn't cause changes to all subsequent sentences.  An exception
-to this exception are multiple sentences in a single bullet point.
- - Indentations use two spaces, no tabs.  Continuations use four spaces.
- - Attributes and methods are typically separated by two newlines.  An
-exception are attributes with getters and setters which can be written
-without separating newlines.
- - All source files end with two newlines.
-
-## Vagrant-based development environment
-
-Before using Vagrant, make sure that Onionoo builds correctly on the host
-system.
-This may require running `git submodule init && git submodule update`, as
-well as providing all required libraries.
-
-The given Vagrant file uses Version 2, i.e., a Vagrant installation
-of version 1.1 or above is necessary.
-The following was tested using 1.4.3 and VirtualBox 4.3.14.
-(Wheezy stable only provides 1.0.3, Jessie provides 1.4.3)
-
-Local changes to the Vagrantfile:
-Tell Vagrant how much memory the virtual machine may use, i.e., change
-
-```
-vb.memory = 4096
-```
-
-to some value that makes sense on your machine.
-Rule of thumb: less than half the RAM, but as much as you want to spare.
-
-Create a Debian Wheezy 64 bit instance:
-
-```
-vagrant up
-```
-
-This command downloads the virtual machine imagine, unless it has been
-downloaded before, creates a new virtual machine, and runs the bootstrap
-script in `vagrant/bootstrap.sh`.  This may take a few minutes.
-
-Once this is all done, log into the virtual machine and change to the
-Onionoo working directory:
-
-```
-vagrant ssh
-cd /srv/onionoo.torproject.org/onionoo/
-```
-
-Important: better avoid runninng Ant in the `/vagrant/` directory (which
-is shared with the host), or the guest system will write directly to the
-host system, which performs not really well.
-
-Read the INSTALL file and make the appropriate changes to adapt everything
-to your setup, e.g., memory settings.
+Please refer to our Contributor and Java coding style documents
+available in The Tor Project's wiki:
+https://trac.torproject.org/projects/tor/wiki/org/teams/MetricsTeam/Documentation#guides
 
 ## Documentation overview
 
diff --git a/Vagrantfile b/Vagrantfile
deleted file mode 100644
index c30e452..000
--- a/Vagrantfile
+++ /dev/null
@@ -1,19 +0,0 @@
-VAGRANTFILE_API_VERSION = "2"
-
-Vagrant.configure(VAGRANTFILE_API_VERSION) do |config|
-
-  config.vm.box = "wheezy64"
-  config.vm.box_url = 
"http://puppet-vagrant-boxes.puppetlabs.com/debian-73-x64-virtualbox-puppet.box;
-
-  config.vm.boot_timeout = 60
-
-  config.vm.network "forwarded_port", guest: 8080, host: 8080
-
-  config.vm.provider "virtualbox" do |vb|
-vb.memory = 4096
-  end
-
-  config.vm.provision :shell, :path => "vagrant/bootstrap.sh"
-
-end
-
diff --git a/vagrant/bootstrap.sh b/vagrant/bootstrap.sh
deleted file mode 100644
index 13138cc..000
--- a/vagrant/bootstrap.sh
+++ /dev/null
@@ -1,30 +0,0 @@
-#!/usr/bin/env bash
-
-echo "Starting provisioning."
-
-echo "Updating package list and upgrading existing packages."
-apt-get update
-apt-get -y upgrade
-
-echo 

[tor-commits] [chutney/master] Configure a ControlPort for every tor instance run by chutney

2016-07-27 Thread teor
commit a68c4538f2bd584be9a838ac365433cabfc2b5e8
Author: teor (Tim Wilson-Brown) 
Date:   Wed Jul 27 16:30:43 2016 +1000

Configure a ControlPort for every tor instance run by chutney

(Not just for clients.)

Implements feature #19765.
---
 torrc_templates/client.tmpl | 1 -
 torrc_templates/common.i| 2 ++
 2 files changed, 2 insertions(+), 1 deletion(-)

diff --git a/torrc_templates/client.tmpl b/torrc_templates/client.tmpl
index b7b6859..e0fbad9 100644
--- a/torrc_templates/client.tmpl
+++ b/torrc_templates/client.tmpl
@@ -1,6 +1,5 @@
 ${include:common.i}
 SocksPort $socksport
-ControlPort $controlport
 CookieAuthentication 1
 
 #NOTE: Setting TestingClientConsensusDownloadSchedule doesn't
diff --git a/torrc_templates/common.i b/torrc_templates/common.i
index e244565..2776ca1 100644
--- a/torrc_templates/common.i
+++ b/torrc_templates/common.i
@@ -46,3 +46,5 @@ ProtocolWarnings 1
 SafeLogging 0
 DisableDebuggerAttachment 0
 ${authorities}
+
+ControlPort $controlport

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits
diff --git a/tools/test-network.sh b/tools/test-network.sh
index 4f1fdbe..0c5fdeb 100755
--- a/tools/test-network.sh
+++ b/tools/test-network.sh
@@ -177,11 +177,11 @@ fi
 cd "$CHUTNEY_PATH"
 ./tools/bootstrap-network.sh "$NETWORK_FLAVOUR" || exit 2
 
 # chutney starts verifying after 15 seconds, keeps on trying for 60 seconds,
 # and then stops immediately (by default)
-# Even the fastest chutney networks take 5 seconds for their first consensus
+# Even the fastest chutney networks take 5-10 seconds for their first consensus
 # and then 10 seconds after that for relays to bootstrap and upload descriptors
-CHUTNEY_START_TIME=${CHUTNEY_START_TIME:-15}
+CHUTNEY_START_TIME=${CHUTNEY_START_TIME:-20}
 CHUTNEY_BOOTSTRAP_TIME=${CHUTNEY_BOOTSTRAP_TIME:-60}
 CHUTNEY_STOP_TIME=${CHUTNEY_STOP_TIME:-0}
 



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-onioncircuits_completed] Update translations for tails-onioncircuits_completed

2016-07-27 Thread translation
commit 972cecc8569193387309c7d1d0f9002388828341
Author: Translation commit bot 
Date:   Wed Jul 27 23:48:48 2016 +

Update translations for tails-onioncircuits_completed
---
 pt/onioncircuits.pot | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
@@ -177,11 +177,11 @@ fi
 ./tools/bootstrap-network.sh "$NETWORK_FLAVOUR" || exit 2
 
-# chutney starts verifying after 15 seconds, keeps on trying for 60 seconds,
+# chutney starts verifying after 20 seconds, keeps on trying for 60 seconds,
 # and then stops immediately (by default)
